Description Details Active bindings Methods
R6 class representing a process (a list of transitions
R6 class representing a process (a list of transitions
Not much here but a fancy list...
sizethe number of transitions in the process
new()Used as Process$new(...) to create a new process from a set of transtions
Process$new(...)
...transitions combined to create the process
a 'Process' object
insert()insert a new transition into the process.
Process$insert(x)
xtransition to insert
invisible NULL
get_transition()retrieve a transition by index
Process$get_transition(i)
iindex of the transition to retrieve
a transition
clone()The objects of this class are cloneable with this method.
Process$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.