Description Details Active bindings Methods
R6 class representing a single transition
R6 class representing a single transition
The transition has a process name, conditions it occurs under, and transformations that it applies to a node
The condition ("match") are specified as in 'dplyr::filter' using the node attributes to match against. The transformations follow the same approach as 'dplyr::mutate' where a data mask basd on the attribute names is searched prior to checking for varaible names in the quosure environments.
idof the transition
processprocess name stored by the transition
matchprocess match stored by the transition
transformationprocess transformation stored by the transition
new()Used as Transition$new(...) create a new transition
Transition$new(process, match, transformation)
processname of the process described by the transformation
matchlist of conditions that the process applies to
transformationlist of transformations to use on the process
a 'Transition' object
clone()The objects of this class are cloneable with this method.
Transition$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.